# Usage with Cylc workflow manager (Advanced)

The command line interface can be used with cylc in a range of environments.

Examples of use can be found in the examples directory of the repository:

- [pip](https://github.com/autoresearch/autora-workflow/tree/main/examples/cylc-pip)
- [conda](https://github.com/autoresearch/autora-workflow/tree/main/examples/cylc-conda)
- [SLURM & pip](https://github.com/autoresearch/autora-workflow/tree/main/examples/cylc-slurm-pip)
